@@ -4,14 +4,6 @@ from pycuda.compiler import SourceModule
 import numpy as np
 import math
 import time
-import lowpy as lp
-import os.path
-# For importing the .cu file from the lowpy package:
-try:
-    import importlib.resources as pkg_resources
-except ImportError:
-    # Try backported to PY<37 `importlib_resources`.
-    import importlib_resources as pkg_resources
 
 # Start timer from 0
 def tic():
@@ -80,14 +72,7 @@ class Dense:
         self.hits_h     = np.zeros(self.J_h,dtype=np.float64)
         self.hits_d     = self.hostToDevice(self.hits_h)
         # Cuda programs
-        # try:
-        #     self.program = SourceModule(open('lowpy/dense.cu','r').read())
-        # except FileNotFoundError:
-        #     self.program = SourceModule(pkg_resources.read_text(lp, 'dense.cu'))
-        if os.path.isfile('lowpy/dense.cu'):# Differentiates between package cuda file and local
-            self.program = SourceModule(open('lowpy/dense.cu','r').read())
-        else:
-            self.program = SourceModule(pkg_resources.read_text(lp, 'dense.cu'))
+        self.program = SourceModule(open("dense.cu").read())
         self.propagateFunction = self.program.get_function("propagate")
         self.propagateFunction.prepare("PPPPPP")
         self.backpropagateFunction = self.program.get_function("backpropagate")
